<img src = "res/GRID_logo.png" width = 100>

# GRID

[![](https://img.shields.io/pypi/pyversions/photo_grid.svg?logo=python&logoColor=white)](https://pypi.org/project/photo-grid/)
[![](https://img.shields.io/pypi/dm/photo_grid.svg?label=pypi%20downloads&logo=python&logoColor=white)](https://pypi.org/project/photo-grid/)
[![](https://img.shields.io/pypi/v/photo_grid.svg?label=pypi%20version&logo=python&logoColor=white)](https://pypi.org/project/photo-grid/)
[![](https://api.codacy.com/project/badge/Grade/626008b19df543ecb33a78e8f82f5e91)](https://app.codacy.com/manual/Poissonfish/photo_grid/dashboard)
[![](https://img.shields.io/github/license/poissonfish/photo_grid)](https://github.com/Poissonfish/photo_grid/blob/master/LICENSE)
[![](https://img.shields.io/github/languages/code-size/poissonfish/photo_grid)](https://github.com/Poissonfish/photo_grid/search?l=Python)

### [Software Page (zzlab.net)](https://zzlab.net/GRID)

### [User Manual](https://poissonfish.github.io/GRID)

## Get Started
### Installation
***Highly recommended install GRID in [Conda](https://poissonfish.github.io/GRID/installation.html) environment***

```pip install photo_grid```
### Launch GRID
```python -m grid```

## Update Log

### Dec 19, 2019 (0.2.46)
    * Add plot variation in the output file
    * Support saving segmentated images as H5 file
    * Now it's possible to display RGB in the plot searching panel.
    * Other minor bug fixes

### Dec 9, 2019 (0.2.45)
    * Bug fixes for image rotating issue
    * Support map with duplicated names

### Oct 29, 2019 (0.2.0)
    * Add progress bars
    * Enhance the support for low resolution monitors
    * Improve UI
  
### Oct 22, 2019 (0.1.3)
    * Optimize default setting of refining parameters
    * Fix wrong angle detection
    * Minor bug fixes

### Oct 19, 2019 (0.1.2)
    * Support rhombus field layout
    * Bug fixes

### Sep 17, 2019 (0.0.16)
    * Improve memory efficiency on Windows OS

### Sep 12, 2019 (0.0.15)
    * Fix problems wiht fixed segmentation
    * Organize file structure
    * Add dark mode
